

DALResults
=========================

.. currentmodule:: pyvo.dal.query

.. autoclass:: DALResults
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~DALResults.nrecs
      ~DALResults.protocol
      ~DALResults.queryurl
      ~DALResults.table
      ~DALResults.version

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~DALResults.cursor
      ~DALResults.fielddesc
      ~DALResults.fieldname_with_ucd
      ~DALResults.fieldname_with_utype
      ~DALResults.fieldnames
      ~DALResults.getcolumn
      ~DALResults.getdesc
      ~DALResults.getrecord
      ~DALResults.getvalue

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: nrecs
   .. autoattribute:: protocol
   .. autoattribute:: queryurl
   .. autoattribute:: table
   .. autoattribute:: version

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: cursor
   .. automethod:: fielddesc
   .. automethod:: fieldname_with_ucd
   .. automethod:: fieldname_with_utype
   .. automethod:: fieldnames
   .. automethod:: getcolumn
   .. automethod:: getdesc
   .. automethod:: getrecord
   .. automethod:: getvalue

   
   